@@ -9,8 +9,7 @@ import typer
 import yaml
 from rich.console import Console
 
-from data_manifestor import core, version
-from data_manifestor.example import hello
+from data_manifestor import core, exceptions, version
 
 
 class Color(str, Enum):
@@ -30,6 +29,16 @@ app = typer.Typer(
 console = Console()
 
 
+def dump_object_to_file(value, path):
+    with open(path, "w") as f:
+        json.dump(
+            value,
+            f,
+            sort_keys=True,
+            indent=4,
+        )
+
+
 def version_callback(print_version: bool) -> None:
     """Print the version of the package."""
     if print_version:
@@ -39,15 +48,6 @@ def version_callback(print_version: bool) -> None:
 
 @app.command(name="")
 def main(
-    name: str = typer.Option(..., help="Person to greet."),
-    color: Optional[Color] = typer.Option(
-        None,
-        "-c",
-        "--color",
-        "--colour",
-        case_sensitive=False,
-        help="Color for print. If not specified then choice will be random.",
-    ),
     print_version: bool = typer.Option(
         None,
         "-v",
@@ -57,12 +57,7 @@ def main(
         help="Prints the version of the data_manifestor package.",
     ),
 ) -> None:
-    """Print a greeting with a giving name."""
-    if color is None:
-        color = choice(list(Color))
-
-    greeting: str = hello(name)
-    console.print(f"[bold {color}]{greeting}[/]")
+    """Prints version."""
 
 
 @app.command()
@@ -73,6 +68,7 @@ def find_files(
     subject_id: str,
     date_str: str,
     output_path: str,
+    missing_output_path: str,
     fail_if_missing: bool = typer.Option(
         None,
         "-f",
@@ -84,24 +80,36 @@ def find_files(
         template = yaml.load(f, Loader=yaml.Loader)
 
     results = core.compare_manifest_to_local(
-        template,
         directory,
         lims_id,
         subject_id,
         date_str,
+        template_dict=template,
     )
 
-    filepaths = []
+    found = []
+    missing = []
     for (
         pattern,
         paths,
     ) in results.resolved_paths:
-        if fail_if_missing and not len(paths) > 0:
-            raise Exception("Path not found for: %s" % pattern)
-        filepaths.extend(paths)
+        if not len(paths) > 0:
+            missing.append(pattern)
+        else:
+            found.extend(paths)
 
-    with open(output_path, "w") as f:
-        json.dump(filepaths, f)
+    dump_object_to_file(
+        found,
+        output_path,
+    )
+
+    dump_object_to_file(
+        missing,
+        missing_output_path,
+    )
+
+    if fail_if_missing and len(missing) > 0:
+        raise exceptions.PathError("Path not found for: %s" % pattern)
 
 
 if __name__ == "__main__":
