@@ -26,3 +26,5 @@ class LocalComparisonResult:
     manifest: Manifest
     local_dir: str
     resolved_paths: list[tuple[str, list[str]]] = field(default_factory=list)
+    found: list[str] = field(default_factory=list)
+    missing: list[str] = field(default_factory=list)
