@@ -4,18 +4,18 @@ import os
 from glob import glob
 
 
-class PathException(Exception):
-    """Pathing related Exception for more specific error handling."""
-
-
 def resolve_paths(
     parent_dir: str,
     path_pattern: str,
 ) -> tuple[str, list[str]]:
-    path = os.path.join(parent_dir, path_pattern)
+    search_pattern = os.path.join(parent_dir, path_pattern)
+    if os.path.isdir(search_pattern):
+        search_pattern = os.path.join(
+            search_pattern, "*"
+        )  # so we can glob all children
     return (
-        path,
-        glob(path),
+        search_pattern,
+        glob(search_pattern),
     )
 
 
@@ -29,7 +29,7 @@ def generate_path_pattern(
     try:
         return full_pattern.format(*args)
     except IndexError:
-        raise PathException(
+        raise Exception(
             "Incompatible path_pattern and args combination. path_pattern=%s, args=%s",
             full_pattern,
             args,
